<?php

namespace Drupal\rater8_review_block\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a dynamic block with configurable Rater8 ID for displaying reviews.
 *
 * @Block(
 *   id = "rater8_review_block",
 *   admin_label = @Translation("Rater8 Reviews"),
 *   category = @Translation("Custom Block"),
 * )
 */
class Rater8ReviewBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'id' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Rater8 ID'),
      '#default_value' => $this->configuration['id'],
      '#required' => TRUE,
      '#size' => 25,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['id'] = $form_state->getValue('id');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $id = $this->configuration['id'];

    $content = [
      '#markup' => $this->t('<div id="rater8Badge"></div>
      <style>
        #block-olivero-rater8reviews {
          display: flex;
          align-content: center;
          justify-content: center;
          max-width: 1030px;
          margin-left: auto;
          margin-right: auto;
        }
        #block-olivero-rater8reviews .block__title {
          margin-block: auto;
          flex: 1 0 auto;
          font-size: 48px;
        }
        #rater8Badge {
          padding-left: 50px;
          margin-left: 20px !important;
          border-left: 1px solid #e3e3e3;
        }
        #rater8Badge .ratecount span, 
        #rater8Badge .ratingsumm img {
          display: inline;
        }
        #rater8Badge .ratingsumm font {
          font-size: 16px;
          font-weight: normal;
        }
        #rater8Badge .ratingsumm div {
          text-align: left !important;
        }
        #rater8Badge .ratingsumm .ratecount {
          padding-left: 0;
        }
      </style>
      <script>
          setTimeout(() => {
            var s1 = document.createElement("script"), s0 = document.getElementsByTagName("script")[0];
            s1.src = "https://reviews.rater8.com/scripts/bluebird.min.js";
            s0.parentNode.insertBefore(s1, s0);

            var s3 = document.createElement("script"), s2 = document.getElementsByTagName("script")[1];
            s3.src = "https://reviews.rater8.com/scripts/fetch.umd.js";
            s2.parentNode.insertBefore(s3, s2);

            function showBadge(physicianId, locationId, format) {
              fetch("https://reviews.rater8.com/webwidget/api/ratingsummary/' . $id . '?format=" + format)
                .then(function(response) {
                  return response.text();
                })
                .then(function(snippet) {
                  document.getElementById(locationId).innerHTML = snippet;
                })
                .catch(function(error) {
                  console.error("Error fetching rater8 badge:", error);
                });
            }

            showBadge("' . $id . '", "rater8Badge", "htmlphysicianrating");

          }, 500);
          </script>'),
      '#attached' => [
        'drupalSettings' => [
          'rater8_review_block' => [
            'id' => $id,
          ],
        ],
      ],
    ];

    return $content;
  }

}
